"use strict";
this.name        = "towbarPayout-Medium";
this.author      = "Dybal";
this.copyright   = "2020 Dybal";
this.licence     = "CC BY-NC-SA 4.0";
this.description = "Alternative payout policy for salvaged equipments";

this.$display = "Medium"; // for use by Towbar in Lib_Config

this.startUpComplete = function() {
    var wstb = worldScripts.towbar;

    if (wstb) {
        if (wstb.$TowbarEquipmentPayoutHandlers) {
            // Towbar version >= 0.105
            log(this.name, "Registering Towbar Equipment Payout handler '"+this.$display+"'");
            wstb.$TowbarEquipmentPayoutHandlers.push(this.$Towbar_EqPayout_Medium);
            this.$Towbar_EqPayout_Medium.display = this.$display;
        } else if (wstb.$Towbar_EqSalvagePrice) {
            // Towbar version 0.104
            log(this.name, "Overwriting Towbar Equipment Payout handler");
            wstb.$Towbar_EqSalvagePrice = this.$Towbar_EqPayout_Medium;
        }
    }
}

this.$Towbar_EqPayout_Medium = function _Towbar_EqPayout_Medium(eqInfo) {
    if (!eqInfo || !eqInfo.equipmentKey) return 0;
    var price = eqInfo.price / 10; // price in credits
    var rnd = Math.random();
    var damage_prob = 0.5 + ((eqInfo.techLevel<16 ? eqInfo.techLevel : Math.random()*15)-6)/20;
    var damaged = (rnd < damage_prob);
    var discounted = 0.25 * price;
    var salvage_price;

    if (discounted < 10) return 0;

    if (damaged) 
        price = discounted / 2;
    else
        price = discounted;
    if (price > 500) // 500 Cr
        salvage_price = 5 * price / Math.sqrt(price/2);
    else
        salvage_price = price;
    if (price > 300) // 300 Cr
        salvage_price = Math.max(50, salvage_price); // at least 50 Cr
    else
        salvage_price = Math.max(10, salvage_price); // at least 10 Cr
    salvage_price = Math.round(salvage_price / 10) * 10; // get multiple of 10 number
    if (this.$TowbarDebug) log(this.name,"towbarPayout-Medium "+eqInfo.equipmentKey+", TL:"+eqInfo.techLevel+", price:"+(eqInfo.price/10).toFixed(0)+", damage_prob:"+damage_prob.toFixed(4)+", damaged:"+damaged+", discounted:"+discounted.toFixed(0)+", depreciated:"+price.toFixed(0)+", payout:"+salvage_price.toFixed(0));
    return salvage_price;
}
